Referenced Specifications
=========================

This library is (partially) compliant with following specifications:

* `RFC8152: CBOR Object Signing and Encryption (COSE)`_
* `RFC8230: Using RSA Algorithms with COSE Messages`_
* `RFC8392: CBOR Web Token (CWT)`_
* `RFC8747: Proof-of-Possession Key Semantics for CBOR Web Tokens (CWTs)`_
* `RFC8812: COSE and JOSE Registrations for Web Authentication (WebAuthn) Algorithms`_

.. _`RFC8152: CBOR Object Signing and Encryption (COSE)`: https://tools.ietf.org/html/rfc8152
.. _`RFC8230: Using RSA Algorithms with COSE Messages`: https://tools.ietf.org/html/rfc8230
.. _`RFC8392: CBOR Web Token (CWT)`: https://tools.ietf.org/html/rfc8392
.. _`RFC8747: Proof-of-Possession Key Semantics for CBOR Web Tokens (CWTs)`: https://tools.ietf.org/html/rfc8747
.. _`RFC8812: COSE and JOSE Registrations for Web Authentication (WebAuthn) Algorithms`: https://tools.ietf.org/html/rfc8812
